from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Approx import *
from OCC.Core.AppParCurves import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.IntSurf import *
from OCC.Core.math import *
from OCC.Core.TColStd import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.IntImp import *
from OCC.Core.gp import *
from OCC.Core.ApproxInt import *
from OCC.Core.TColgp import *


class BRepApprox_Approx:
	def __init__(self) -> None: ...
	def IsDone(self) -> bool: ...
	def NbMultiCurves(self) -> int: ...
	def SetParameters(self, Tol3d: float, Tol2d: float, DegMin: int, DegMax: int, NbIterMax: int, NbPntMax: Optional[int] = 30, ApproxWithTangency: Optional[bool] = True, Parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength) -> None: ...
	def TolReached2d(self) -> float: ...
	def TolReached3d(self) -> float: ...
	def Value(self, Index: int) -> AppParCurves_MultiBSpCurve: ...

class BRepApprox_ApproxLine(Standard_Transient):
	@overload
	def __init__(self, CurveXYZ: Geom_BSplineCurve, CurveUV1: Geom2d_BSplineCurve, CurveUV2: Geom2d_BSplineCurve) -> None: ...
	@overload
	def __init__(self, lin: IntSurf_LineOn2S, theTang: Optional[bool] = False) -> None: ...
	def NbPnts(self) -> int: ...
	def Point(self, Index: int) -> IntSurf_PntOn2S: ...

class BRepApprox_BSpGradient_BFGSOfMyBSplGradientOfTheComputeLineOfApprox(math_BFGS):
	def __init__(self, F: math_MultipleVarFunctionWithGradient, StartingPoint: math_Vector, Tolerance3d: float, Tolerance2d: float, Eps: float, NbIterations: Optional[int] = 200) -> None: ...
	def IsSolutionReached(self, F: math_MultipleVarFunctionWithGradient) -> bool: ...

class BRepApprox_BSpParFunctionOfMyBSplGradientOfTheComputeLineOfApprox(math_MultipleVarFunctionWithGradient):
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NbPol: int) -> None: ...
	def CurveValue(self) -> AppParCurves_MultiBSpCurve: ...
	def DerivativeFunctionMatrix(self) -> math_Matrix: ...
	def Error(self, IPoint: int, CurveIndex: int) -> float: ...
	def FirstConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, FirstPoint: int) -> AppParCurves_Constraint: ...
	def FunctionMatrix(self) -> math_Matrix: ...
	def Gradient(self, X: math_Vector, G: math_Vector) -> bool: ...
	def Index(self) -> math_IntegerVector: ...
	def LastConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, LastPoint: int) -> AppParCurves_Constraint: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def NbVariables(self) -> int: ...
	def NewParameters(self) -> math_Vector: ...
	def SetFirstLambda(self, l1: float) -> None: ...
	def SetLastLambda(self, l2: float) -> None: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...
	def Values(self, X: math_Vector, G: math_Vector) -> Tuple[bool, float]: ...

class BRepApprox_BSpParLeastSquareOfMyBSplGradientOfTheComputeLineOfApprox:
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	def BSplineValue(self) -> AppParCurves_MultiBSpCurve: ...
	def BezierValue(self) -> AppParCurves_MultiCurve: ...
	def DerivativeFunctionMatrix(self) -> math_Matrix: ...
	def Distance(self) -> math_Matrix: ...
	def Error(self) -> Tuple[float, float, float]: ...
	def ErrorGradient(self, Grad: math_Vector) -> Tuple[float, float, float]: ...
	def FirstLambda(self) -> float: ...
	def FunctionMatrix(self) -> math_Matrix: ...
	def IsDone(self) -> bool: ...
	def KIndex(self) -> math_IntegerVector: ...
	def LastLambda(self) -> float: ...
	@overload
	def Perform(self, Parameters: math_Vector) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, V1c: math_Vector, V2c: math_Vector, l1: float, l2: float) -> None: ...
	def Points(self) -> math_Matrix: ...
	def Poles(self) -> math_Matrix: ...

class BRepApprox_Gradient_BFGSOfMyGradientOfTheComputeLineBezierOfApprox(math_BFGS):
	def __init__(self, F: math_MultipleVarFunctionWithGradient, StartingPoint: math_Vector, Tolerance3d: float, Tolerance2d: float, Eps: float, NbIterations: Optional[int] = 200) -> None: ...
	def IsSolutionReached(self, F: math_MultipleVarFunctionWithGradient) -> bool: ...

class BRepApprox_Gradient_BFGSOfMyGradientbisOfTheComputeLineOfApprox(math_BFGS):
	def __init__(self, F: math_MultipleVarFunctionWithGradient, StartingPoint: math_Vector, Tolerance3d: float, Tolerance2d: float, Eps: float, NbIterations: Optional[int] = 200) -> None: ...
	def IsSolutionReached(self, F: math_MultipleVarFunctionWithGradient) -> bool: ...

class BRepApprox_MyBSplGradientOfTheComputeLineOfApprox:
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Deg: int, Tol3d: float, Tol2d: float, NbIterations: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Deg: int, Tol3d: float, Tol2d: float, NbIterations: int, lambda1: float, lambda2: float) -> None: ...
	def AverageError(self) -> float: ...
	def Error(self, Index: int) -> float: ...
	def IsDone(self) -> bool: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def Value(self) -> AppParCurves_MultiBSpCurve: ...

class BRepApprox_MyGradientOfTheComputeLineBezierOfApprox:
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Deg: int, Tol3d: float, Tol2d: float, NbIterations: Optional[int] = 200) -> None: ...
	def AverageError(self) -> float: ...
	def Error(self, Index: int) -> float: ...
	def IsDone(self) -> bool: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def Value(self) -> AppParCurves_MultiCurve: ...

class BRepApprox_MyGradientbisOfTheComputeLineOfApprox:
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Deg: int, Tol3d: float, Tol2d: float, NbIterations: Optional[int] = 200) -> None: ...
	def AverageError(self) -> float: ...
	def Error(self, Index: int) -> float: ...
	def IsDone(self) -> bool: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def Value(self) -> AppParCurves_MultiCurve: ...

class BRepApprox_ParFunctionOfMyGradientOfTheComputeLineBezierOfApprox(math_MultipleVarFunctionWithGradient):
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Deg: int) -> None: ...
	def CurveValue(self) -> AppParCurves_MultiCurve: ...
	def Error(self, IPoint: int, CurveIndex: int) -> float: ...
	def FirstConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, FirstPoint: int) -> AppParCurves_Constraint: ...
	def Gradient(self, X: math_Vector, G: math_Vector) -> bool: ...
	def LastConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, LastPoint: int) -> AppParCurves_Constraint: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def NbVariables(self) -> int: ...
	def NewParameters(self) -> math_Vector: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...
	def Values(self, X: math_Vector, G: math_Vector) -> Tuple[bool, float]: ...

class BRepApprox_ParFunctionOfMyGradientbisOfTheComputeLineOfApprox(math_MultipleVarFunctionWithGradient):
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, TheConstraints: AppParCurves_HArray1OfConstraintCouple, Parameters: math_Vector, Deg: int) -> None: ...
	def CurveValue(self) -> AppParCurves_MultiCurve: ...
	def Error(self, IPoint: int, CurveIndex: int) -> float: ...
	def FirstConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, FirstPoint: int) -> AppParCurves_Constraint: ...
	def Gradient(self, X: math_Vector, G: math_Vector) -> bool: ...
	def LastConstraint(self, TheConstraints: AppParCurves_HArray1OfConstraintCouple, LastPoint: int) -> AppParCurves_Constraint: ...
	def MaxError2d(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def NbVariables(self) -> int: ...
	def NewParameters(self) -> math_Vector: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...
	def Values(self, X: math_Vector, G: math_Vector) -> Tuple[bool, float]: ...

class BRepApprox_ParLeastSquareOfMyGradientOfTheComputeLineBezierOfApprox:
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	def BSplineValue(self) -> AppParCurves_MultiBSpCurve: ...
	def BezierValue(self) -> AppParCurves_MultiCurve: ...
	def DerivativeFunctionMatrix(self) -> math_Matrix: ...
	def Distance(self) -> math_Matrix: ...
	def Error(self) -> Tuple[float, float, float]: ...
	def ErrorGradient(self, Grad: math_Vector) -> Tuple[float, float, float]: ...
	def FirstLambda(self) -> float: ...
	def FunctionMatrix(self) -> math_Matrix: ...
	def IsDone(self) -> bool: ...
	def KIndex(self) -> math_IntegerVector: ...
	def LastLambda(self) -> float: ...
	@overload
	def Perform(self, Parameters: math_Vector) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, V1c: math_Vector, V2c: math_Vector, l1: float, l2: float) -> None: ...
	def Points(self) -> math_Matrix: ...
	def Poles(self) -> math_Matrix: ...

class BRepApprox_ParLeastSquareOfMyGradientbisOfTheComputeLineOfApprox:
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, Parameters: math_Vector, NbPol: int) -> None: ...
	@overload
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, FirstPoint: int, LastPoint: int, FirstCons: AppParCurves_Constraint, LastCons: AppParCurves_Constraint, NbPol: int) -> None: ...
	def BSplineValue(self) -> AppParCurves_MultiBSpCurve: ...
	def BezierValue(self) -> AppParCurves_MultiCurve: ...
	def DerivativeFunctionMatrix(self) -> math_Matrix: ...
	def Distance(self) -> math_Matrix: ...
	def Error(self) -> Tuple[float, float, float]: ...
	def ErrorGradient(self, Grad: math_Vector) -> Tuple[float, float, float]: ...
	def FirstLambda(self) -> float: ...
	def FunctionMatrix(self) -> math_Matrix: ...
	def IsDone(self) -> bool: ...
	def KIndex(self) -> math_IntegerVector: ...
	def LastLambda(self) -> float: ...
	@overload
	def Perform(self, Parameters: math_Vector) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, l1: float, l2: float) -> None: ...
	@overload
	def Perform(self, Parameters: math_Vector, V1t: math_Vector, V2t: math_Vector, V1c: math_Vector, V2c: math_Vector, l1: float, l2: float) -> None: ...
	def Points(self) -> math_Matrix: ...
	def Poles(self) -> math_Matrix: ...

class BRepApprox_ResConstraintOfMyGradientOfTheComputeLineBezierOfApprox:
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, SCurv: AppParCurves_MultiCurve, FirstPoint: int, LastPoint: int, Constraints: AppParCurves_HArray1OfConstraintCouple, Bern: math_Matrix, DerivativeBern: math_Matrix, Tolerance: Optional[float] = 1.0e-10) -> None: ...
	def ConstraintDerivative(self, SSP: BRepApprox_TheMultiLineOfApprox, Parameters: math_Vector, Deg: int, DA: math_Matrix) -> math_Matrix: ...
	def ConstraintMatrix(self) -> math_Matrix: ...
	def Duale(self) -> math_Vector: ...
	def InverseMatrix(self) -> math_Matrix: ...
	def IsDone(self) -> bool: ...

class BRepApprox_ResConstraintOfMyGradientbisOfTheComputeLineOfApprox:
	def __init__(self, SSP: BRepApprox_TheMultiLineOfApprox, SCurv: AppParCurves_MultiCurve, FirstPoint: int, LastPoint: int, Constraints: AppParCurves_HArray1OfConstraintCouple, Bern: math_Matrix, DerivativeBern: math_Matrix, Tolerance: Optional[float] = 1.0e-10) -> None: ...
	def ConstraintDerivative(self, SSP: BRepApprox_TheMultiLineOfApprox, Parameters: math_Vector, Deg: int, DA: math_Matrix) -> math_Matrix: ...
	def ConstraintMatrix(self) -> math_Matrix: ...
	def Duale(self) -> math_Vector: ...
	def InverseMatrix(self) -> math_Matrix: ...
	def IsDone(self) -> bool: ...

class BRepApprox_TheComputeLineBezierOfApprox:
	@overload
	def __init__(self, Line: BRepApprox_TheMultiLineOfApprox, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-3, Tolerance2d: Optional[float] = 1.0e-6, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Line: BRepApprox_TheMultiLineOfApprox, Parameters: math_Vector, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Parameters: math_Vector, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	def ChangeValue(self, Index: Optional[int] = 1) -> AppParCurves_MultiCurve: ...
	def Error(self, Index: int) -> Tuple[float, float]: ...
	def Init(self, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	def IsAllApproximated(self) -> bool: ...
	def IsToleranceReached(self) -> bool: ...
	def NbMultiCurves(self) -> int: ...
	def Parameters(self, Index: Optional[int] = 1) -> TColStd_Array1OfReal: ...
	def Parametrization(self) -> Approx_ParametrizationType: ...
	def Perform(self, Line: BRepApprox_TheMultiLineOfApprox) -> None: ...
	def SetConstraints(self, firstC: AppParCurves_Constraint, lastC: AppParCurves_Constraint) -> None: ...
	def SetDegrees(self, degreemin: int, degreemax: int) -> None: ...
	def SetTolerances(self, Tolerance3d: float, Tolerance2d: float) -> None: ...
	def SplineValue(self) -> AppParCurves_MultiBSpCurve: ...
	def Value(self, Index: Optional[int] = 1) -> AppParCurves_MultiCurve: ...

class BRepApprox_TheComputeLineOfApprox:
	@overload
	def __init__(self, Line: BRepApprox_TheMultiLineOfApprox, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-3, Tolerance2d: Optional[float] = 1.0e-6, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Line: BRepApprox_TheMultiLineOfApprox, Parameters: math_Vector, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Parameters: math_Vector, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, Squares: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	def ChangeValue(self) -> AppParCurves_MultiBSpCurve: ...
	def Error(self) -> Tuple[float, float]: ...
	def Init(self, degreemin: Optional[int] = 4, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-03, Tolerance2d: Optional[float] = 1.0e-06, NbIterations: Optional[int] = 5, cutting: Optional[bool] = True, parametrization: Optional[Approx_ParametrizationType] = Approx_ChordLength, Squares: Optional[bool] = False) -> None: ...
	def Interpol(self, Line: BRepApprox_TheMultiLineOfApprox) -> None: ...
	def IsAllApproximated(self) -> bool: ...
	def IsToleranceReached(self) -> bool: ...
	def Parameters(self) -> TColStd_Array1OfReal: ...
	def Perform(self, Line: BRepApprox_TheMultiLineOfApprox) -> None: ...
	def SetConstraints(self, firstC: AppParCurves_Constraint, lastC: AppParCurves_Constraint) -> None: ...
	def SetContinuity(self, C: int) -> None: ...
	def SetDegrees(self, degreemin: int, degreemax: int) -> None: ...
	def SetKnots(self, Knots: TColStd_Array1OfReal) -> None: ...
	def SetKnotsAndMultiplicities(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> None: ...
	def SetParameters(self, ThePar: math_Vector) -> None: ...
	def SetPeriodic(self, thePeriodic: bool) -> None: ...
	def SetTolerances(self, Tolerance3d: float, Tolerance2d: float) -> None: ...
	def Value(self) -> AppParCurves_MultiBSpCurve: ...

class BRepApprox_TheFunctionOfTheInt2SOfThePrmPrmSvSurfacesOfApprox(math_FunctionSetWithDerivatives):
	def __init__(self, S1: BRepAdaptor_Surface, S2: BRepAdaptor_Surface) -> None: ...
	def AuxillarSurface1(self) -> BRepAdaptor_Surface: ...
	def AuxillarSurface2(self) -> BRepAdaptor_Surface: ...
	def ComputeParameters(self, ChoixIso: IntImp_ConstIsoparametric, Param: TColStd_Array1OfReal, UVap: math_Vector, BornInf: math_Vector, BornSup: math_Vector, Tolerance: math_Vector) -> None: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def Direction(self) -> gp_Dir: ...
	def DirectionOnS1(self) -> gp_Dir2d: ...
	def DirectionOnS2(self) -> gp_Dir2d: ...
	def IsTangent(self, UVap: math_Vector, Param: TColStd_Array1OfReal, BestChoix: IntImp_ConstIsoparametric) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class BRepApprox_TheImpPrmSvSurfacesOfApprox(ApproxInt_SvSurfaces):
	@overload
	def __init__(self, Surf1: BRepAdaptor_Surface, Surf2: IntSurf_Quadric) -> None: ...
	@overload
	def __init__(self, Surf1: IntSurf_Quadric, Surf2: BRepAdaptor_Surface) -> None: ...
	def Compute(self, Pt: gp_Pnt, Tg: gp_Vec, Tguv1: gp_Vec2d, Tguv2: gp_Vec2d) -> Tuple[bool, float, float, float, float]: ...
	def Pnt(self, u1: float, v1: float, u2: float, v2: float, P: gp_Pnt) -> None: ...
	def SeekPoint(self, u1: float, v1: float, u2: float, v2: float, Point: IntSurf_PntOn2S) -> bool: ...
	def Tangency(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec) -> bool: ...
	def TangencyOnSurf1(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec2d) -> bool: ...
	def TangencyOnSurf2(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec2d) -> bool: ...

class BRepApprox_TheInt2SOfThePrmPrmSvSurfacesOfApprox:
	@overload
	def __init__(self, Param: TColStd_Array1OfReal, S1: BRepAdaptor_Surface, S2: BRepAdaptor_Surface, TolTangency: float) -> None: ...
	@overload
	def __init__(self, S1: BRepAdaptor_Surface, S2: BRepAdaptor_Surface, TolTangency: float) -> None: ...
	def ChangePoint(self) -> IntSurf_PntOn2S: ...
	def Direction(self) -> gp_Dir: ...
	def DirectionOnS1(self) -> gp_Dir2d: ...
	def DirectionOnS2(self) -> gp_Dir2d: ...
	def Function(self) -> BRepApprox_TheFunctionOfTheInt2SOfThePrmPrmSvSurfacesOfApprox: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsTangent(self) -> bool: ...
	@overload
	def Perform(self, Param: TColStd_Array1OfReal, Rsnld: math_FunctionSetRoot) -> IntImp_ConstIsoparametric: ...
	@overload
	def Perform(self, Param: TColStd_Array1OfReal, Rsnld: math_FunctionSetRoot, ChoixIso: IntImp_ConstIsoparametric) -> IntImp_ConstIsoparametric: ...
	def Point(self) -> IntSurf_PntOn2S: ...

class BRepApprox_TheMultiLineOfApprox:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, line: BRepApprox_ApproxLine, PtrSvSurfaces: None, NbP3d: int, NbP2d: int, ApproxU1V1: bool, ApproxU2V2: bool, xo: float, yo: float, zo: float, u1o: float, v1o: float, u2o: float, v2o: float, P2DOnFirst: bool, IndMin: Optional[int] = 0, IndMax: Optional[int] = 0) -> None: ...
	@overload
	def __init__(self, line: BRepApprox_ApproxLine, NbP3d: int, NbP2d: int, ApproxU1V1: bool, ApproxU2V2: bool, xo: float, yo: float, zo: float, u1o: float, v1o: float, u2o: float, v2o: float, P2DOnFirst: bool, IndMin: Optional[int] = 0, IndMax: Optional[int] = 0) -> None: ...
	def Dump(self) -> None: ...
	def FirstPoint(self) -> int: ...
	def LastPoint(self) -> int: ...
	def MakeMLBetween(self, Low: int, High: int, NbPointsToInsert: int) -> BRepApprox_TheMultiLineOfApprox: ...
	def MakeMLOneMorePoint(self, Low: int, High: int, indbad: int, OtherLine: BRepApprox_TheMultiLineOfApprox) -> bool: ...
	def NbP2d(self) -> int: ...
	def NbP3d(self) -> int: ...
	@overload
	def Tangency(self, MPointIndex: int, tabV: TColgp_Array1OfVec) -> bool: ...
	@overload
	def Tangency(self, MPointIndex: int, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@overload
	def Tangency(self, MPointIndex: int, tabV: TColgp_Array1OfVec, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@overload
	def Value(self, MPointIndex: int, tabPt: TColgp_Array1OfPnt) -> None: ...
	@overload
	def Value(self, MPointIndex: int, tabPt2d: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def Value(self, MPointIndex: int, tabPt: TColgp_Array1OfPnt, tabPt2d: TColgp_Array1OfPnt2d) -> None: ...
	def WhatStatus(self) -> Approx_Status: ...

class BRepApprox_TheMultiLineToolOfApprox:
	@overload
	@staticmethod
	def Curvature(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV: TColgp_Array1OfVec) -> bool: ...
	@overload
	@staticmethod
	def Curvature(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@overload
	@staticmethod
	def Curvature(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV: TColgp_Array1OfVec, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@staticmethod
	def Dump(ML: BRepApprox_TheMultiLineOfApprox) -> None: ...
	@staticmethod
	def FirstPoint(ML: BRepApprox_TheMultiLineOfApprox) -> int: ...
	@staticmethod
	def LastPoint(ML: BRepApprox_TheMultiLineOfApprox) -> int: ...
	@staticmethod
	def MakeMLBetween(ML: BRepApprox_TheMultiLineOfApprox, I1: int, I2: int, NbPMin: int) -> BRepApprox_TheMultiLineOfApprox: ...
	@staticmethod
	def MakeMLOneMorePoint(ML: BRepApprox_TheMultiLineOfApprox, I1: int, I2: int, indbad: int, OtherLine: BRepApprox_TheMultiLineOfApprox) -> bool: ...
	@staticmethod
	def NbP2d(ML: BRepApprox_TheMultiLineOfApprox) -> int: ...
	@staticmethod
	def NbP3d(ML: BRepApprox_TheMultiLineOfApprox) -> int: ...
	@overload
	@staticmethod
	def Tangency(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV: TColgp_Array1OfVec) -> bool: ...
	@overload
	@staticmethod
	def Tangency(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@overload
	@staticmethod
	def Tangency(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabV: TColgp_Array1OfVec, tabV2d: TColgp_Array1OfVec2d) -> bool: ...
	@overload
	@staticmethod
	def Value(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabPt: TColgp_Array1OfPnt) -> None: ...
	@overload
	@staticmethod
	def Value(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabPt2d: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	@staticmethod
	def Value(ML: BRepApprox_TheMultiLineOfApprox, MPointIndex: int, tabPt: TColgp_Array1OfPnt, tabPt2d: TColgp_Array1OfPnt2d) -> None: ...
	@staticmethod
	def WhatStatus(ML: BRepApprox_TheMultiLineOfApprox, I1: int, I2: int) -> Approx_Status: ...

class BRepApprox_ThePrmPrmSvSurfacesOfApprox(ApproxInt_SvSurfaces):
	def __init__(self, Surf1: BRepAdaptor_Surface, Surf2: BRepAdaptor_Surface) -> None: ...
	def Compute(self, Pt: gp_Pnt, Tg: gp_Vec, Tguv1: gp_Vec2d, Tguv2: gp_Vec2d) -> Tuple[bool, float, float, float, float]: ...
	def Pnt(self, u1: float, v1: float, u2: float, v2: float, P: gp_Pnt) -> None: ...
	def SeekPoint(self, u1: float, v1: float, u2: float, v2: float, Point: IntSurf_PntOn2S) -> bool: ...
	def Tangency(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec) -> bool: ...
	def TangencyOnSurf1(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec2d) -> bool: ...
	def TangencyOnSurf2(self, u1: float, v1: float, u2: float, v2: float, Tg: gp_Vec2d) -> bool: ...

class BRepApprox_TheZerImpFuncOfTheImpPrmSvSurfacesOfApprox(math_FunctionSetWithDerivatives):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, PS: BRepAdaptor_Surface, IS: IntSurf_Quadric) -> None: ...
	@overload
	def __init__(self, IS: IntSurf_Quadric) -> None: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def Direction2d(self) -> gp_Dir2d: ...
	def Direction3d(self) -> gp_Vec: ...
	def ISurface(self) -> IntSurf_Quadric: ...
	def IsTangent(self) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def PSurface(self) -> BRepAdaptor_Surface: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	@overload
	def Set(self, PS: BRepAdaptor_Surface) -> None: ...
	@overload
	def Set(self, Tolerance: float) -> None: ...
	def SetImplicitSurface(self, IS: IntSurf_Quadric) -> None: ...
	def Tolerance(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes

BRepApprox_TheMultiLineToolOfApprox_Curvature = BRepApprox_TheMultiLineToolOfApprox.Curvature
BRepApprox_TheMultiLineToolOfApprox_Curvature = BRepApprox_TheMultiLineToolOfApprox.Curvature
BRepApprox_TheMultiLineToolOfApprox_Curvature = BRepApprox_TheMultiLineToolOfApprox.Curvature
BRepApprox_TheMultiLineToolOfApprox_Dump = BRepApprox_TheMultiLineToolOfApprox.Dump
BRepApprox_TheMultiLineToolOfApprox_FirstPoint = BRepApprox_TheMultiLineToolOfApprox.FirstPoint
BRepApprox_TheMultiLineToolOfApprox_LastPoint = BRepApprox_TheMultiLineToolOfApprox.LastPoint
BRepApprox_TheMultiLineToolOfApprox_MakeMLBetween = BRepApprox_TheMultiLineToolOfApprox.MakeMLBetween
BRepApprox_TheMultiLineToolOfApprox_MakeMLOneMorePoint = BRepApprox_TheMultiLineToolOfApprox.MakeMLOneMorePoint
BRepApprox_TheMultiLineToolOfApprox_NbP2d = BRepApprox_TheMultiLineToolOfApprox.NbP2d
BRepApprox_TheMultiLineToolOfApprox_NbP3d = BRepApprox_TheMultiLineToolOfApprox.NbP3d
BRepApprox_TheMultiLineToolOfApprox_Tangency = BRepApprox_TheMultiLineToolOfApprox.Tangency
BRepApprox_TheMultiLineToolOfApprox_Tangency = BRepApprox_TheMultiLineToolOfApprox.Tangency
BRepApprox_TheMultiLineToolOfApprox_Tangency = BRepApprox_TheMultiLineToolOfApprox.Tangency
BRepApprox_TheMultiLineToolOfApprox_Value = BRepApprox_TheMultiLineToolOfApprox.Value
BRepApprox_TheMultiLineToolOfApprox_Value = BRepApprox_TheMultiLineToolOfApprox.Value
BRepApprox_TheMultiLineToolOfApprox_Value = BRepApprox_TheMultiLineToolOfApprox.Value
BRepApprox_TheMultiLineToolOfApprox_WhatStatus = BRepApprox_TheMultiLineToolOfApprox.WhatStatus



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
LProp3d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_lprop3d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _LProp3d
else:
    import _LProp3d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _LProp3d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _LProp3d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LProp3d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LProp3d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _LProp3d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _LProp3d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _LProp3d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _LProp3d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _LProp3d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _LProp3d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LProp3d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _LProp3d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _LProp3d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LProp3d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LProp3d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LProp3d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _LProp3d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _LProp3d:
_LProp3d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _LProp3d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *



class LProp3d_CLProps(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the local properties of the curve <c> the current point and the derivatives are computed at the same time, which allows an optimization of the computation time. <n> indicates the maximum number of derivations to be done (0, 1, 2 or 3). for example, to compute only the tangent, n should be equal to 1. <resolution> is the linear tolerance (it is used to test if a vector is null).

        Parameters
        ----------
        C: Adaptor3d_HCurve
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u>. all the computations done will be related to <c> and <u>.

        Parameters
        ----------
        C: Adaptor3d_HCurve
        U: float
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u> and the curve is set with setcurve. the curve can have a empty constructor all the computations done will be related to <c> and <u> when the functions 'set' will be done.

        Parameters
        ----------
        N: int
        Resolution: float

        Returns
        -------
        None

        """
        _LProp3d.LProp3d_CLProps_swiginit(self, _LProp3d.new_LProp3d_CLProps(*args))

    def CentreOfCurvature(self, *args) -> "void":
        r"""
        Returns the centre of curvature <p>.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CLProps_CentreOfCurvature(self, *args)

    def Curvature(self, *args) -> "Standard_Real":
        r"""
        Returns the curvature.

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_CLProps_Curvature(self, *args)

    def D1(self, *args) -> "gp_Vec const":
        r"""
        Returns the first derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_CLProps_D1(self, *args)

    def D2(self, *args) -> "gp_Vec const":
        r"""
        Returns the second derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_CLProps_D2(self, *args)

    def D3(self, *args) -> "gp_Vec const":
        r"""
        Returns the third derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_CLProps_D3(self, *args)

    def IsTangentDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the tangent is defined. for example, the tangent is not defined if the three first derivatives are all null.

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_CLProps_IsTangentDefined(self, *args)

    def Normal(self, *args) -> "void":
        r"""
        Returns the normal direction <n>.

        Parameters
        ----------
        N: gp_Dir

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CLProps_Normal(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the new curve.

        Parameters
        ----------
        C: Adaptor3d_HCurve

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CLProps_SetCurve(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the parameter value <u>.

        Parameters
        ----------
        U: float

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CLProps_SetParameter(self, *args)

    def Tangent(self, *args) -> "void":
        r"""
        Output the tangent direction <d>.

        Parameters
        ----------
        D: gp_Dir

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CLProps_Tangent(self, *args)

    def Value(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point.

        Returns
        -------
        gp_Pnt

        """
        return _LProp3d.LProp3d_CLProps_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LProp3d.delete_LProp3d_CLProps

# Register LProp3d_CLProps in _LProp3d:
_LProp3d.LProp3d_CLProps_swigregister(LProp3d_CLProps)

class LProp3d_CurveTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Continuity(*args) -> "Standard_Integer":
        r"""
        Returns the order of continuity of the hcurve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

        Parameters
        ----------
        C: Adaptor3d_HCurve

        Returns
        -------
        int

        """
        return _LProp3d.LProp3d_CurveTool_Continuity(*args)

    @staticmethod
    def D1(*args) -> "void":
        r"""
        Computes the point <p> and first derivative <v1> of parameter <u> on the hcurve <c>.

        Parameters
        ----------
        C: Adaptor3d_HCurve
        U: float
        P: gp_Pnt
        V1: gp_Vec

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CurveTool_D1(*args)

    @staticmethod
    def D2(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the hcurve <c>.

        Parameters
        ----------
        C: Adaptor3d_HCurve
        U: float
        P: gp_Pnt
        V1: gp_Vec
        V2: gp_Vec

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CurveTool_D2(*args)

    @staticmethod
    def D3(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the hcurve <c>.

        Parameters
        ----------
        C: Adaptor3d_HCurve
        U: float
        P: gp_Pnt
        V1: gp_Vec
        V2: gp_Vec
        V3: gp_Vec

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CurveTool_D3(*args)

    @staticmethod
    def FirstParameter(*args) -> "Standard_Real":
        r"""
        Returns the first parameter bound of the hcurve.

        Parameters
        ----------
        C: Adaptor3d_HCurve

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_CurveTool_FirstParameter(*args)

    @staticmethod
    def LastParameter(*args) -> "Standard_Real":
        r"""
        Returns the last parameter bound of the hcurve. firstparameter must be less than lastparamenter.

        Parameters
        ----------
        C: Adaptor3d_HCurve

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_CurveTool_LastParameter(*args)

    @staticmethod
    def Value(*args) -> "void":
        r"""
        Computes the point <p> of parameter <u> on the hcurve <c>.

        Parameters
        ----------
        C: Adaptor3d_HCurve
        U: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_CurveTool_Value(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _LProp3d.LProp3d_CurveTool_swiginit(self, _LProp3d.new_LProp3d_CurveTool())
    __swig_destroy__ = _LProp3d.delete_LProp3d_CurveTool

# Register LProp3d_CurveTool in _LProp3d:
_LProp3d.LProp3d_CurveTool_swigregister(LProp3d_CurveTool)

def LProp3d_CurveTool_Continuity(*args) -> "Standard_Integer":
    r"""
    Returns the order of continuity of the hcurve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

    Parameters
    ----------
    C: Adaptor3d_HCurve

    Returns
    -------
    int

    """
    return _LProp3d.LProp3d_CurveTool_Continuity(*args)

def LProp3d_CurveTool_D1(*args) -> "void":
    r"""
    Computes the point <p> and first derivative <v1> of parameter <u> on the hcurve <c>.

    Parameters
    ----------
    C: Adaptor3d_HCurve
    U: float
    P: gp_Pnt
    V1: gp_Vec

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_CurveTool_D1(*args)

def LProp3d_CurveTool_D2(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the hcurve <c>.

    Parameters
    ----------
    C: Adaptor3d_HCurve
    U: float
    P: gp_Pnt
    V1: gp_Vec
    V2: gp_Vec

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_CurveTool_D2(*args)

def LProp3d_CurveTool_D3(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the hcurve <c>.

    Parameters
    ----------
    C: Adaptor3d_HCurve
    U: float
    P: gp_Pnt
    V1: gp_Vec
    V2: gp_Vec
    V3: gp_Vec

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_CurveTool_D3(*args)

def LProp3d_CurveTool_FirstParameter(*args) -> "Standard_Real":
    r"""
    Returns the first parameter bound of the hcurve.

    Parameters
    ----------
    C: Adaptor3d_HCurve

    Returns
    -------
    float

    """
    return _LProp3d.LProp3d_CurveTool_FirstParameter(*args)

def LProp3d_CurveTool_LastParameter(*args) -> "Standard_Real":
    r"""
    Returns the last parameter bound of the hcurve. firstparameter must be less than lastparamenter.

    Parameters
    ----------
    C: Adaptor3d_HCurve

    Returns
    -------
    float

    """
    return _LProp3d.LProp3d_CurveTool_LastParameter(*args)

def LProp3d_CurveTool_Value(*args) -> "void":
    r"""
    Computes the point <p> of parameter <u> on the hcurve <c>.

    Parameters
    ----------
    C: Adaptor3d_HCurve
    U: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_CurveTool_Value(*args)

class LProp3d_SLProps(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the local properties of the surface <s> for the parameter values (<u>, <v>). the current point and the derivatives are computed at the same time, which allows an optimization of the computation time. <n> indicates the maximum number of derivations to be done (0, 1, or 2). for example, to compute only the tangent, n should be equal to 1. <resolution> is the linear tolerance (it is used to test if a vector is null).

        Parameters
        ----------
        S: Adaptor3d_HSurface
        U: float
        V: float
        N: int
        Resolution: float

        Returns
        -------
        None
        Idem as previous constructor but without setting the value of parameters <u> and <v>.

        Parameters
        ----------
        S: Adaptor3d_HSurface
        N: int
        Resolution: float

        Returns
        -------
        None
        Idem as previous constructor but without setting the value of parameters <u> and <v> and the surface. the surface can have an empty constructor.

        Parameters
        ----------
        N: int
        Resolution: float

        Returns
        -------
        None

        """
        _LProp3d.LProp3d_SLProps_swiginit(self, _LProp3d.new_LProp3d_SLProps(*args))

    def CurvatureDirections(self, *args) -> "void":
        r"""
        Returns the direction of the maximum and minimum curvature <maxd> and <mind>.

        Parameters
        ----------
        MaxD: gp_Dir
        MinD: gp_Dir

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SLProps_CurvatureDirections(self, *args)

    def D1U(self, *args) -> "gp_Vec const":
        r"""
        Returns the first u derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SLProps_D1U(self, *args)

    def D1V(self, *args) -> "gp_Vec const":
        r"""
        Returns the first v derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SLProps_D1V(self, *args)

    def D2U(self, *args) -> "gp_Vec const":
        r"""
        Returns the second u derivatives the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SLProps_D2U(self, *args)

    def D2V(self, *args) -> "gp_Vec const":
        r"""
        Returns the second v derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SLProps_D2V(self, *args)

    def DUV(self, *args) -> "gp_Vec const":
        r"""
        Returns the second uv cross-derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SLProps_DUV(self, *args)

    def GaussianCurvature(self, *args) -> "Standard_Real":
        r"""
        Returns the gaussian curvature.

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_SLProps_GaussianCurvature(self, *args)

    def IsCurvatureDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the curvature is defined.

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_SLProps_IsCurvatureDefined(self, *args)

    def IsNormalDefined(self, *args) -> "Standard_Boolean":
        r"""
        Tells if the normal is defined.

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_SLProps_IsNormalDefined(self, *args)

    def IsTangentUDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the u tangent is defined. for example, the tangent is not defined if the two first u derivatives are null.

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_SLProps_IsTangentUDefined(self, *args)

    def IsTangentVDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns if the v tangent is defined. for example, the tangent is not defined if the two first v derivatives are null.

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_SLProps_IsTangentVDefined(self, *args)

    def IsUmbilic(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the point is umbilic (i.e. if the curvature is constant).

        Returns
        -------
        bool

        """
        return _LProp3d.LProp3d_SLProps_IsUmbilic(self, *args)

    def MaxCurvature(self, *args) -> "Standard_Real":
        r"""
        Returns the maximum curvature.

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_SLProps_MaxCurvature(self, *args)

    def MeanCurvature(self, *args) -> "Standard_Real":
        r"""
        Returns the mean curvature.

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_SLProps_MeanCurvature(self, *args)

    def MinCurvature(self, *args) -> "Standard_Real":
        r"""
        Returns the minimum curvature.

        Returns
        -------
        float

        """
        return _LProp3d.LProp3d_SLProps_MinCurvature(self, *args)

    def Normal(self, *args) -> "gp_Dir const":
        r"""
        Returns the normal direction.

        Returns
        -------
        gp_Dir

        """
        return _LProp3d.LProp3d_SLProps_Normal(self, *args)

    def SetParameters(self, *args) -> "void":
        r"""
        Initializes the local properties of the surface s for the new parameter values (<u>, <v>).

        Parameters
        ----------
        U: float
        V: float

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SLProps_SetParameters(self, *args)

    def SetSurface(self, *args) -> "void":
        r"""
        Initializes the local properties of the surface s for the new surface.

        Parameters
        ----------
        S: Adaptor3d_HSurface

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SLProps_SetSurface(self, *args)

    def TangentU(self, *args) -> "void":
        r"""
        Returns the tangent direction <d> on the iso-v.

        Parameters
        ----------
        D: gp_Dir

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SLProps_TangentU(self, *args)

    def TangentV(self, *args) -> "void":
        r"""
        Returns the tangent direction <d> on the iso-v.

        Parameters
        ----------
        D: gp_Dir

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SLProps_TangentV(self, *args)

    def Value(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point.

        Returns
        -------
        gp_Pnt

        """
        return _LProp3d.LProp3d_SLProps_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LProp3d.delete_LProp3d_SLProps

# Register LProp3d_SLProps in _LProp3d:
_LProp3d.LProp3d_SLProps_swigregister(LProp3d_SLProps)

class LProp3d_SurfaceTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Bounds(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &":
        r"""
        Returns the bounds of the hsurface.

        Parameters
        ----------
        S: Adaptor3d_HSurface

        Returns
        -------
        U1: float
        V1: float
        U2: float
        V2: float

        """
        return _LProp3d.LProp3d_SurfaceTool_Bounds(*args)

    @staticmethod
    def Continuity(*args) -> "Standard_Integer":
        r"""
        Returns the order of continuity of the hsurface <s>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable.

        Parameters
        ----------
        S: Adaptor3d_HSurface

        Returns
        -------
        int

        """
        return _LProp3d.LProp3d_SurfaceTool_Continuity(*args)

    @staticmethod
    def D1(*args) -> "void":
        r"""
        Computes the point <p> and first derivative <d1*> of parameter <u> and <v> on the hsurface <s>.

        Parameters
        ----------
        S: Adaptor3d_HSurface
        U: float
        V: float
        P: gp_Pnt
        D1U: gp_Vec
        D1V: gp_Vec

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SurfaceTool_D1(*args)

    @staticmethod
    def D2(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <d1*> and second derivative <d2*> of parameter <u> and <v> on the hsurface <s>.

        Parameters
        ----------
        S: Adaptor3d_HSurface
        U: float
        V: float
        P: gp_Pnt
        D1U: gp_Vec
        D1V: gp_Vec
        D2U: gp_Vec
        D2V: gp_Vec
        DUV: gp_Vec

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SurfaceTool_D2(*args)

    @staticmethod
    def DN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        S: Adaptor3d_HSurface
        U: float
        V: float
        IU: int
        IV: int

        Returns
        -------
        gp_Vec

        """
        return _LProp3d.LProp3d_SurfaceTool_DN(*args)

    @staticmethod
    def Value(*args) -> "void":
        r"""
        Computes the point <p> of parameter <u> and <v> on the hsurface <s>.

        Parameters
        ----------
        S: Adaptor3d_HSurface
        U: float
        V: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _LProp3d.LProp3d_SurfaceTool_Value(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _LProp3d.LProp3d_SurfaceTool_swiginit(self, _LProp3d.new_LProp3d_SurfaceTool())
    __swig_destroy__ = _LProp3d.delete_LProp3d_SurfaceTool

# Register LProp3d_SurfaceTool in _LProp3d:
_LProp3d.LProp3d_SurfaceTool_swigregister(LProp3d_SurfaceTool)

def LProp3d_SurfaceTool_Bounds(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &":
    r"""
    Returns the bounds of the hsurface.

    Parameters
    ----------
    S: Adaptor3d_HSurface

    Returns
    -------
    U1: float
    V1: float
    U2: float
    V2: float

    """
    return _LProp3d.LProp3d_SurfaceTool_Bounds(*args)

def LProp3d_SurfaceTool_Continuity(*args) -> "Standard_Integer":
    r"""
    Returns the order of continuity of the hsurface <s>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable.

    Parameters
    ----------
    S: Adaptor3d_HSurface

    Returns
    -------
    int

    """
    return _LProp3d.LProp3d_SurfaceTool_Continuity(*args)

def LProp3d_SurfaceTool_D1(*args) -> "void":
    r"""
    Computes the point <p> and first derivative <d1*> of parameter <u> and <v> on the hsurface <s>.

    Parameters
    ----------
    S: Adaptor3d_HSurface
    U: float
    V: float
    P: gp_Pnt
    D1U: gp_Vec
    D1V: gp_Vec

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_SurfaceTool_D1(*args)

def LProp3d_SurfaceTool_D2(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <d1*> and second derivative <d2*> of parameter <u> and <v> on the hsurface <s>.

    Parameters
    ----------
    S: Adaptor3d_HSurface
    U: float
    V: float
    P: gp_Pnt
    D1U: gp_Vec
    D1V: gp_Vec
    D2U: gp_Vec
    D2V: gp_Vec
    DUV: gp_Vec

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_SurfaceTool_D2(*args)

def LProp3d_SurfaceTool_DN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    S: Adaptor3d_HSurface
    U: float
    V: float
    IU: int
    IV: int

    Returns
    -------
    gp_Vec

    """
    return _LProp3d.LProp3d_SurfaceTool_DN(*args)

def LProp3d_SurfaceTool_Value(*args) -> "void":
    r"""
    Computes the point <p> of parameter <u> and <v> on the hsurface <s>.

    Parameters
    ----------
    S: Adaptor3d_HSurface
    U: float
    V: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _LProp3d.LProp3d_SurfaceTool_Value(*args)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TopTrans module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_toptrans.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopTrans
else:
    import _TopTrans

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopTrans.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TopTrans.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopTrans.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopTrans.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TopTrans.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TopTrans.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TopTrans.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TopTrans.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TopTrans.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TopTrans.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopTrans.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TopTrans.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TopTrans.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopTrans.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopTrans.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopTrans.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TopTrans.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopTrans:
_TopTrans.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TopTrans.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TopAbs

from enum import IntEnum
from OCC.Core.Exception import *



class TopTrans_Array2OfOrientation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopTrans.TopTrans_Array2OfOrientation_swiginit(self, _TopTrans.new_TopTrans_Array2OfOrientation(*args))

    def Init(self, theValue: "TopAbs_Orientation const &") -> "void":
        return _TopTrans.TopTrans_Array2OfOrientation_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_Length(self)

    def NbRows(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_NbRows(self)

    def NbColumns(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_NbColumns(self)

    def RowLength(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_RowLength(self)

    def ColLength(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_ColLength(self)

    def LowerRow(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_LowerRow(self)

    def UpperRow(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_UpperRow(self)

    def LowerCol(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_LowerCol(self)

    def UpperCol(self) -> "Standard_Integer":
        return _TopTrans.TopTrans_Array2OfOrientation_UpperCol(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TopTrans.TopTrans_Array2OfOrientation_IsDeletable(self)

    def Assign(self, theOther: "TopTrans_Array2OfOrientation") -> "NCollection_Array2< TopAbs_Orientation > &":
        return _TopTrans.TopTrans_Array2OfOrientation_Assign(self, theOther)

    def Move(self, theOther: "TopTrans_Array2OfOrientation") -> "NCollection_Array2< TopAbs_Orientation > &":
        return _TopTrans.TopTrans_Array2OfOrientation_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array2< TopAbs_Orientation > &":
        return _TopTrans.TopTrans_Array2OfOrientation_Set(self, *args)

    def Value(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "TopAbs_Orientation const &":
        return _TopTrans.TopTrans_Array2OfOrientation_Value(self, theRow, theCol)

    def ChangeValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "TopAbs_Orientation &":
        return _TopTrans.TopTrans_Array2OfOrientation_ChangeValue(self, theRow, theCol)

    def __call__(self, *args) -> "TopAbs_Orientation &":
        return _TopTrans.TopTrans_Array2OfOrientation___call__(self, *args)

    def SetValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const", theItem: "TopAbs_Orientation const &") -> "void":
        return _TopTrans.TopTrans_Array2OfOrientation_SetValue(self, theRow, theCol, theItem)

    def Resize(self, theRowLower: "Standard_Integer", theRowUpper: "Standard_Integer", theColLower: "Standard_Integer", theColUpper: "Standard_Integer", theToCopyData: "Standard_Boolean") -> "void":
        return _TopTrans.TopTrans_Array2OfOrientation_Resize(self, theRowLower, theRowUpper, theColLower, theColUpper, theToCopyData)
    __swig_destroy__ = _TopTrans.delete_TopTrans_Array2OfOrientation

# Register TopTrans_Array2OfOrientation in _TopTrans:
_TopTrans.TopTrans_Array2OfOrientation_swigregister(TopTrans_Array2OfOrientation)

class TopTrans_CurveTransition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an empty curve transition.

        Returns
        -------
        None

        """
        _TopTrans.TopTrans_CurveTransition_swiginit(self, _TopTrans.new_TopTrans_CurveTransition(*args))

    def Compare(self, *args) -> "void":
        r"""
        Add a curve element to the boundary. if or is reversed the curve is before the intersection, else if or is forward the curv is after the intersection and if or is internal the intersection is in the middle of the curv.

        Parameters
        ----------
        Tole: float
        Tang: gp_Dir
        Norm: gp_Dir
        Curv: float
        S: TopAbs_Orientation
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _TopTrans.TopTrans_CurveTransition_Compare(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Initialize a transition with the local description of a curve.

        Parameters
        ----------
        Tgt: gp_Dir
        Norm: gp_Dir
        Curv: float

        Returns
        -------
        None
        Initialize a transition with the local description of a straigth line.

        Parameters
        ----------
        Tgt: gp_Dir

        Returns
        -------
        None

        """
        return _TopTrans.TopTrans_CurveTransition_Reset(self, *args)

    def StateAfter(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of the curve after the intersection, this is the position relative to the boundary of a point very close to the intersection on the positive side of the tangent.

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_CurveTransition_StateAfter(self, *args)

    def StateBefore(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of the curve before the intersection, this is the position relative to the boundary of a point very close to the intersection on the negative side of the tangent.

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_CurveTransition_StateBefore(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopTrans.delete_TopTrans_CurveTransition

# Register TopTrans_CurveTransition in _TopTrans:
_TopTrans.TopTrans_CurveTransition_swigregister(TopTrans_CurveTransition)

class TopTrans_SurfaceTransition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an empty surface transition.

        Returns
        -------
        None

        """
        _TopTrans.TopTrans_SurfaceTransition_swiginit(self, _TopTrans.new_TopTrans_SurfaceTransition(*args))

    def Compare(self, *args) -> "void":
        r"""
        Add a face element to the boundary. //! - s defines topological orientation for the face : s forward means: along the intersection curve on the reference surface, transition states while crossing the face are out,in. s reversed means states are in,out. s internal means states are in,in. //! - o defines curve's position on face : o forward means the face is before the intersection o reversed means the face is after o internal means the curve intersection is in the face. prequesitory : norm oriented outside 'geometric matter'.

        Parameters
        ----------
        Tole: float
        Norm: gp_Dir
        MaxD: gp_Dir
        MinD: gp_Dir
        MaxCurv: float
        MinCurv: float
        S: TopAbs_Orientation
        O: TopAbs_Orientation

        Returns
        -------
        None
        Add a plane or a cylindric face to the boundary.

        Parameters
        ----------
        Tole: float
        Norm: gp_Dir
        S: TopAbs_Orientation
        O: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _TopTrans.TopTrans_SurfaceTransition_Compare(self, *args)

    @staticmethod
    def GetAfter(*args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        Tran: TopAbs_Orientation

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_SurfaceTransition_GetAfter(*args)

    @staticmethod
    def GetBefore(*args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        Tran: TopAbs_Orientation

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_SurfaceTransition_GetBefore(*args)

    def Reset(self, *args) -> "void":
        r"""
        Initialize a surface transition with the local description of the intersection curve and of the reference surface. prequesitory : norm oriented outside 'geometric matter'.

        Parameters
        ----------
        Tgt: gp_Dir
        Norm: gp_Dir
        MaxD: gp_Dir
        MinD: gp_Dir
        MaxCurv: float
        MinCurv: float

        Returns
        -------
        None
        Initialize a surface transition with the local description of a straight line.

        Parameters
        ----------
        Tgt: gp_Dir
        Norm: gp_Dir

        Returns
        -------
        None

        """
        return _TopTrans.TopTrans_SurfaceTransition_Reset(self, *args)

    def StateAfter(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of the reference surface after interference, this is the position relative to the surface of a point very close to the intersection on the positive side of the tangent.

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_SurfaceTransition_StateAfter(self, *args)

    def StateBefore(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of the reference surface before the interference, this is the position relative to the surface of a point very close to the intersection on the negative side of the tangent.

        Returns
        -------
        TopAbs_State

        """
        return _TopTrans.TopTrans_SurfaceTransition_StateBefore(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopTrans.delete_TopTrans_SurfaceTransition

# Register TopTrans_SurfaceTransition in _TopTrans:
_TopTrans.TopTrans_SurfaceTransition_swigregister(TopTrans_SurfaceTransition)

def TopTrans_SurfaceTransition_GetAfter(*args) -> "TopAbs_State":
    r"""
    No available documentation.

    Parameters
    ----------
    Tran: TopAbs_Orientation

    Returns
    -------
    TopAbs_State

    """
    return _TopTrans.TopTrans_SurfaceTransition_GetAfter(*args)

def TopTrans_SurfaceTransition_GetBefore(*args) -> "TopAbs_State":
    r"""
    No available documentation.

    Parameters
    ----------
    Tran: TopAbs_Orientation

    Returns
    -------
    TopAbs_State

    """
    return _TopTrans.TopTrans_SurfaceTransition_GetBefore(*args)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Transfer import *
from OCC.Core.StepShape import *
from OCC.Core.TopoDS import *
from OCC.Core.StepRepr import *
from OCC.Core.TopLoc import *
from OCC.Core.StepBasic import *
from OCC.Core.StepAP203 import *
from OCC.Core.Interface import *
from OCC.Core.StepGeom import *
from OCC.Core.StepData import *
from OCC.Core.TCollection import *
from OCC.Core.TColStd import *
from OCC.Core.gp import *
from OCC.Core.XSControl import *
from OCC.Core.StepVisual import *
from OCC.Core.Quantity import *


class stepconstruct:
	@staticmethod
	def FindCDSR(ComponentBinder: Transfer_Binder, AssemblySDR: StepShape_ShapeDefinitionRepresentation, ComponentCDSR: StepShape_ContextDependentShapeRepresentation) -> bool: ...
	@overload
	@staticmethod
	def FindEntity(FinderProcess: Transfer_FinderProcess, Shape: TopoDS_Shape) -> StepRepr_RepresentationItem: ...
	@overload
	@staticmethod
	def FindEntity(FinderProcess: Transfer_FinderProcess, Shape: TopoDS_Shape, Loc: TopLoc_Location) -> StepRepr_RepresentationItem: ...
	@staticmethod
	def FindShape(TransientProcess: Transfer_TransientProcess, item: StepRepr_RepresentationItem) -> TopoDS_Shape: ...

class STEPConstruct_AP203Context:
	def __init__(self) -> None: ...
	def Clear(self) -> None: ...
	def DefaultApproval(self) -> StepBasic_Approval: ...
	def DefaultDateAndTime(self) -> StepBasic_DateAndTime: ...
	def DefaultPersonAndOrganization(self) -> StepBasic_PersonAndOrganization: ...
	def DefaultSecurityClassificationLevel(self) -> StepBasic_SecurityClassificationLevel: ...
	def GetApproval(self) -> StepAP203_CcDesignApproval: ...
	def GetApprovalDateTime(self) -> StepBasic_ApprovalDateTime: ...
	def GetApprover(self) -> StepBasic_ApprovalPersonOrganization: ...
	def GetClassificationDate(self) -> StepAP203_CcDesignDateAndTimeAssignment: ...
	def GetClassificationOfficer(self) -> StepAP203_CcDesignPersonAndOrganizationAssignment: ...
	def GetCreationDate(self) -> StepAP203_CcDesignDateAndTimeAssignment: ...
	def GetCreator(self) -> StepAP203_CcDesignPersonAndOrganizationAssignment: ...
	def GetDesignOwner(self) -> StepAP203_CcDesignPersonAndOrganizationAssignment: ...
	def GetDesignSupplier(self) -> StepAP203_CcDesignPersonAndOrganizationAssignment: ...
	def GetProductCategoryRelationship(self) -> StepBasic_ProductCategoryRelationship: ...
	def GetSecurity(self) -> StepAP203_CcDesignSecurityClassification: ...
	@overload
	def Init(self, sdr: StepShape_ShapeDefinitionRepresentation) -> None: ...
	@overload
	def Init(self, SDRTool: STEPConstruct_Part) -> None: ...
	@overload
	def Init(self, nauo: StepRepr_NextAssemblyUsageOccurrence) -> None: ...
	def InitApprovalRequisites(self) -> None: ...
	def InitAssembly(self, nauo: StepRepr_NextAssemblyUsageOccurrence) -> None: ...
	def InitRoles(self) -> None: ...
	def InitSecurityRequisites(self) -> None: ...
	def RoleApprover(self) -> StepBasic_ApprovalRole: ...
	def RoleClassificationDate(self) -> StepBasic_DateTimeRole: ...
	def RoleClassificationOfficer(self) -> StepBasic_PersonAndOrganizationRole: ...
	def RoleCreationDate(self) -> StepBasic_DateTimeRole: ...
	def RoleCreator(self) -> StepBasic_PersonAndOrganizationRole: ...
	def RoleDesignOwner(self) -> StepBasic_PersonAndOrganizationRole: ...
	def RoleDesignSupplier(self) -> StepBasic_PersonAndOrganizationRole: ...
	def SetDefaultApproval(self, app: StepBasic_Approval) -> None: ...
	def SetDefaultDateAndTime(self, dt: StepBasic_DateAndTime) -> None: ...
	def SetDefaultPersonAndOrganization(self, po: StepBasic_PersonAndOrganization) -> None: ...
	def SetDefaultSecurityClassificationLevel(self, sc: StepBasic_SecurityClassificationLevel) -> None: ...

class STEPConstruct_Assembly:
	def __init__(self) -> None: ...
	@staticmethod
	def CheckSRRReversesNAUO(theGraph: Interface_Graph, CDSR: StepShape_ContextDependentShapeRepresentation) -> bool: ...
	def GetNAUO(self) -> StepRepr_NextAssemblyUsageOccurrence: ...
	def Init(self, aSR: StepShape_ShapeDefinitionRepresentation, SDR0: StepShape_ShapeDefinitionRepresentation, Ax0: StepGeom_Axis2Placement3d, Loc: StepGeom_Axis2Placement3d) -> None: ...
	def ItemLocation(self) -> StepGeom_Axis2Placement3d: ...
	def ItemValue(self) -> Standard_Transient: ...
	def MakeRelationship(self) -> None: ...

class STEPConstruct_ContextTool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aStepModel: StepData_StepModel) -> None: ...
	def AP203Context(self) -> STEPConstruct_AP203Context: ...
	def AddAPD(self, enforce: Optional[bool] = False) -> None: ...
	def GetACname(self) -> TCollection_HAsciiString: ...
	def GetACschemaName(self) -> TCollection_HAsciiString: ...
	def GetACstatus(self) -> TCollection_HAsciiString: ...
	def GetACyear(self) -> int: ...
	def GetAPD(self) -> StepBasic_ApplicationProtocolDefinition: ...
	def GetDefaultAxis(self) -> StepGeom_Axis2Placement3d: ...
	def GetProductName(self) -> TCollection_HAsciiString: ...
	def GetRootsForAssemblyLink(self, assembly: STEPConstruct_Assembly) -> TColStd_HSequenceOfTransient: ...
	def GetRootsForPart(self, SDRTool: STEPConstruct_Part) -> TColStd_HSequenceOfTransient: ...
	def Index(self) -> int: ...
	def IsAP203(self) -> bool: ...
	def IsAP214(self) -> bool: ...
	def IsAP242(self) -> bool: ...
	def Level(self) -> int: ...
	def NextIndex(self) -> None: ...
	def NextLevel(self) -> None: ...
	def PrevIndex(self) -> None: ...
	def PrevLevel(self) -> None: ...
	def SetACname(self, name: TCollection_HAsciiString) -> None: ...
	def SetACschemaName(self, schemaName: TCollection_HAsciiString) -> None: ...
	def SetACstatus(self, status: TCollection_HAsciiString) -> None: ...
	def SetACyear(self, year: int) -> None: ...
	def SetIndex(self, ind: int) -> None: ...
	def SetLevel(self, lev: int) -> None: ...
	def SetModel(self, aStepModel: StepData_StepModel) -> None: ...

class STEPConstruct_Part:
	def __init__(self) -> None: ...
	def AC(self) -> StepBasic_ApplicationContext: ...
	def ACapplication(self) -> TCollection_HAsciiString: ...
	def IsDone(self) -> bool: ...
	def MakeSDR(self, aShape: StepShape_ShapeRepresentation, aName: TCollection_HAsciiString, AC: StepBasic_ApplicationContext) -> None: ...
	def PC(self) -> StepBasic_ProductContext: ...
	def PCdisciplineType(self) -> TCollection_HAsciiString: ...
	def PCname(self) -> TCollection_HAsciiString: ...
	def PD(self) -> StepBasic_ProductDefinition: ...
	def PDC(self) -> StepBasic_ProductDefinitionContext: ...
	def PDCname(self) -> TCollection_HAsciiString: ...
	def PDCstage(self) -> TCollection_HAsciiString: ...
	def PDF(self) -> StepBasic_ProductDefinitionFormation: ...
	def PDFdescription(self) -> TCollection_HAsciiString: ...
	def PDFid(self) -> TCollection_HAsciiString: ...
	def PDS(self) -> StepRepr_ProductDefinitionShape: ...
	def PDSdescription(self) -> TCollection_HAsciiString: ...
	def PDSname(self) -> TCollection_HAsciiString: ...
	def PDdescription(self) -> TCollection_HAsciiString: ...
	def PRPC(self) -> StepBasic_ProductRelatedProductCategory: ...
	def PRPCdescription(self) -> TCollection_HAsciiString: ...
	def PRPCname(self) -> TCollection_HAsciiString: ...
	def Pdescription(self) -> TCollection_HAsciiString: ...
	def Pid(self) -> TCollection_HAsciiString: ...
	def Pname(self) -> TCollection_HAsciiString: ...
	def Product(self) -> StepBasic_Product: ...
	def ReadSDR(self, aShape: StepShape_ShapeDefinitionRepresentation) -> None: ...
	def SDRValue(self) -> StepShape_ShapeDefinitionRepresentation: ...
	def SRValue(self) -> StepShape_ShapeRepresentation: ...
	def SetACapplication(self, text: TCollection_HAsciiString) -> None: ...
	def SetPCdisciplineType(self, label: TCollection_HAsciiString) -> None: ...
	def SetPCname(self, name: TCollection_HAsciiString) -> None: ...
	def SetPDCname(self, label: TCollection_HAsciiString) -> None: ...
	def SetPDCstage(self, label: TCollection_HAsciiString) -> None: ...
	def SetPDFdescription(self, text: TCollection_HAsciiString) -> None: ...
	def SetPDFid(self, id: TCollection_HAsciiString) -> None: ...
	def SetPDSdescription(self, text: TCollection_HAsciiString) -> None: ...
	def SetPDSname(self, label: TCollection_HAsciiString) -> None: ...
	def SetPDdescription(self, text: TCollection_HAsciiString) -> None: ...
	def SetPRPCdescription(self, text: TCollection_HAsciiString) -> None: ...
	def SetPRPCname(self, label: TCollection_HAsciiString) -> None: ...
	def SetPdescription(self, text: TCollection_HAsciiString) -> None: ...
	def SetPid(self, id: TCollection_HAsciiString) -> None: ...
	def SetPname(self, label: TCollection_HAsciiString) -> None: ...

class STEPConstruct_PointHasher:
	@staticmethod
	def HashCode(thePoint: gp_Pnt, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(Point1: gp_Pnt, Point2: gp_Pnt) -> bool: ...

class STEPConstruct_Tool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession) -> None: ...
	def FinderProcess(self) -> Transfer_FinderProcess: ...
	def Graph(self, recompute: Optional[bool] = False) -> Interface_Graph: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...
	def WS(self) -> XSControl_WorkSession: ...

class STEPConstruct_UnitContext:
	def __init__(self) -> None: ...
	def AreaDone(self) -> bool: ...
	def AreaFactor(self) -> float: ...
	@overload
	def ComputeFactors(self, aContext: StepRepr_GlobalUnitAssignedContext) -> int: ...
	@overload
	def ComputeFactors(self, aUnit: StepBasic_NamedUnit) -> int: ...
	def ComputeTolerance(self, aContext: StepRepr_GlobalUncertaintyAssignedContext) -> int: ...
	@staticmethod
	def ConvertSiPrefix(aPrefix: StepBasic_SiPrefix) -> float: ...
	def HasUncertainty(self) -> bool: ...
	def Init(self, Tol3d: float) -> None: ...
	def IsDone(self) -> bool: ...
	def LengthDone(self) -> bool: ...
	def LengthFactor(self) -> float: ...
	def PlaneAngleDone(self) -> bool: ...
	def PlaneAngleFactor(self) -> float: ...
	def SolidAngleDone(self) -> bool: ...
	def SolidAngleFactor(self) -> float: ...
	def StatusMessage(self, status: int) -> str: ...
	def Uncertainty(self) -> float: ...
	def Value(self) -> StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx: ...
	def VolumeDone(self) -> bool: ...
	def VolumeFactor(self) -> float: ...

class STEPConstruct_ExternRefs(STEPConstruct_Tool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession) -> None: ...
	def AddExternRef(self, filename: str, PD: StepBasic_ProductDefinition, format: str) -> int: ...
	def Clear(self) -> None: ...
	def DocFile(self, num: int) -> StepBasic_DocumentFile: ...
	def FileName(self, num: int) -> str: ...
	def Format(self, num: int) -> TCollection_HAsciiString: ...
	def GetAP214APD(self) -> StepBasic_ApplicationProtocolDefinition: ...
	def Init(self, WS: XSControl_WorkSession) -> bool: ...
	def LoadExternRefs(self) -> bool: ...
	def NbExternRefs(self) -> int: ...
	def ProdDef(self, num: int) -> StepBasic_ProductDefinition: ...
	def SetAP214APD(self, APD: StepBasic_ApplicationProtocolDefinition) -> None: ...
	def WriteExternRefs(self, num: int) -> int: ...
	def checkAP214Shared(self) -> None: ...

class STEPConstruct_Styles(STEPConstruct_Tool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession) -> None: ...
	@overload
	def AddStyle(self, style: StepVisual_StyledItem) -> None: ...
	@overload
	def AddStyle(self, item: StepRepr_RepresentationItem, PSA: StepVisual_PresentationStyleAssignment, Override: StepVisual_StyledItem) -> StepVisual_StyledItem: ...
	@overload
	def AddStyle(self, Shape: TopoDS_Shape, PSA: StepVisual_PresentationStyleAssignment, Override: StepVisual_StyledItem) -> StepVisual_StyledItem: ...
	def ClearStyles(self) -> None: ...
	def CreateMDGPR(self, Context: StepRepr_RepresentationContext, MDGPR: StepVisual_MechanicalDesignGeometricPresentationRepresentation) -> bool: ...
	def CreateNAUOSRD(self, Context: StepRepr_RepresentationContext, CDSR: StepShape_ContextDependentShapeRepresentation, initPDS: StepRepr_ProductDefinitionShape) -> bool: ...
	@staticmethod
	def DecodeColor(Colour: StepVisual_Colour, Col: Quantity_Color) -> bool: ...
	@overload
	@staticmethod
	def EncodeColor(Col: Quantity_Color) -> StepVisual_Colour: ...
	@overload
	@staticmethod
	def EncodeColor(Col: Quantity_Color, DPDCs: STEPConstruct_DataMapOfAsciiStringTransient, ColRGBs: STEPConstruct_DataMapOfPointTransient) -> StepVisual_Colour: ...
	def FindContext(self, Shape: TopoDS_Shape) -> StepRepr_RepresentationContext: ...
	def GetColorPSA(self, item: StepRepr_RepresentationItem, Col: StepVisual_Colour) -> StepVisual_PresentationStyleAssignment: ...
	def GetColors(self, style: StepVisual_StyledItem, SurfCol: StepVisual_Colour, BoundCol: StepVisual_Colour, CurveCol: StepVisual_Colour, RenderCol: StepVisual_Colour) -> Tuple[bool, float, bool]: ...
	def Init(self, WS: XSControl_WorkSession) -> bool: ...
	def LoadInvisStyles(self, InvSyles: TColStd_HSequenceOfTransient) -> bool: ...
	def LoadStyles(self) -> bool: ...
	def MakeColorPSA(self, item: StepRepr_RepresentationItem, SurfCol: StepVisual_Colour, CurveCol: StepVisual_Colour, RenderCol: StepVisual_Colour, RenderTransp: float, isForNAUO: Optional[bool] = False) -> StepVisual_PresentationStyleAssignment: ...
	def NbStyles(self) -> int: ...
	def Style(self, i: int) -> StepVisual_StyledItem: ...

class STEPConstruct_ValidationProps(STEPConstruct_Tool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession) -> None: ...
	def AddArea(self, Shape: TopoDS_Shape, Area: float) -> bool: ...
	def AddCentroid(self, Shape: TopoDS_Shape, Pnt: gp_Pnt, instance: Optional[bool] = False) -> bool: ...
	@overload
	def AddProp(self, Shape: TopoDS_Shape, Prop: StepRepr_RepresentationItem, Descr: str, instance: Optional[bool] = False) -> bool: ...
	@overload
	def AddProp(self, target: StepRepr_CharacterizedDefinition, Context: StepRepr_RepresentationContext, Prop: StepRepr_RepresentationItem, Descr: str) -> bool: ...
	def AddVolume(self, Shape: TopoDS_Shape, Vol: float) -> bool: ...
	def FindTarget(self, S: TopoDS_Shape, target: StepRepr_CharacterizedDefinition, Context: StepRepr_RepresentationContext, instance: Optional[bool] = False) -> bool: ...
	def GetPropNAUO(self, PD: StepRepr_PropertyDefinition) -> StepRepr_NextAssemblyUsageOccurrence: ...
	def GetPropPD(self, PD: StepRepr_PropertyDefinition) -> StepBasic_ProductDefinition: ...
	def GetPropPnt(self, item: StepRepr_RepresentationItem, Context: StepRepr_RepresentationContext, Pnt: gp_Pnt) -> bool: ...
	def GetPropReal(self, item: StepRepr_RepresentationItem) -> Tuple[bool, float, bool]: ...
	@overload
	def GetPropShape(self, ProdDef: StepBasic_ProductDefinition) -> TopoDS_Shape: ...
	@overload
	def GetPropShape(self, PD: StepRepr_PropertyDefinition) -> TopoDS_Shape: ...
	def Init(self, WS: XSControl_WorkSession) -> bool: ...
	def LoadProps(self, seq: TColStd_SequenceOfTransient) -> bool: ...
	def SetAssemblyShape(self, shape: TopoDS_Shape) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

stepconstruct_FindCDSR = stepconstruct.FindCDSR
stepconstruct_FindEntity = stepconstruct.FindEntity
stepconstruct_FindEntity = stepconstruct.FindEntity
stepconstruct_FindShape = stepconstruct.FindShape
STEPConstruct_Assembly_CheckSRRReversesNAUO = STEPConstruct_Assembly.CheckSRRReversesNAUO
STEPConstruct_PointHasher_HashCode = STEPConstruct_PointHasher.HashCode
STEPConstruct_PointHasher_IsEqual = STEPConstruct_PointHasher.IsEqual
STEPConstruct_UnitContext_ConvertSiPrefix = STEPConstruct_UnitContext.ConvertSiPrefix
STEPConstruct_Styles_DecodeColor = STEPConstruct_Styles.DecodeColor
STEPConstruct_Styles_EncodeColor = STEPConstruct_Styles.EncodeColor
STEPConstruct_Styles_EncodeColor = STEPConstruct_Styles.EncodeColor
